@@ -4,7 +4,7 @@ import requests
 import os
 import re
 import time
-from .utils.misc import choose, split_name, get_size, convert_html_to_pdf, project
+from .utils.misc import choose, split_name, get_size, convert_html_to_pdf, project, get_size_folder
 from inputimeout import inputimeout, TimeoutOccurred
 
 nh = janda.Nhentai()
@@ -24,7 +24,6 @@ async def get_nh(id: int = choose().nhentai):
     print(f'Total: {len(img)}')
 
     tags = parser['tags']
-    ## jadikan satu variable dari tags list
     tags = [tag for tag in tags]
     print(f'Tags: {tags}')
 
@@ -55,16 +54,13 @@ async def get_nh(id: int = choose().nhentai):
                     f'Successfully downloaded {img_name} | {get_size(neat_dir + "/" + img_name)} MB | took {time.time() - start:.2f} seconds')
 
             if len(img) == len(os.listdir(neat_dir)):
-                print(
-                    f'Successfully downloaded all images in {(time.time() - initial) / 60:.2f} minutes')
+                print(f'Successfully downloaded all images taken {(time.time() - initial) / 60:.2f} minutes with total size {get_size_folder(neat_dir)} MB')
                 with open(neat_dir + '/tomoe.html', 'x', encoding="utf-8") as f:
                     f.write('<html><center><body>')
                     f.write(f"<h1>{parser['details']['id']}</h1>")
    
                     for i in img:
-                        ## get after last slash in img, example /1.jpg
                         file = i.rsplit('/', 1)[-1]
-                        ## print(file)
                         
                         f.write(f'<img src="{neat_dir}/{file}"><p></p>')
                     f.write(f'{project()}')
@@ -83,9 +79,10 @@ async def get_nh(id: int = choose().nhentai):
                         try:
                             source = open(f"{neat_dir}/tomoe.html")
                             output = f"{neat_dir}/{parser['details']['id']}.pdf"
+                            filepdf = output.rsplit('/', 1)[-1]
 
                             convert_html_to_pdf(source, output)
-                            print(f'Successfully converted to {output}')  
+                            print(f'Successfully rendered to {filepdf} | {get_size(output)} MB')   
             
                         except Exception as e:
                             print(
